@@ -175,7 +175,8 @@ void KMailMigrator::migrate()
   deleteOldGroup();
   migrateTags();
   migrateRCFiles();
-
+  migrateNotifyFile();
+  
   // copy autosave files if there are any
   const QString autoSaveDir = KGlobal::dirs()->saveLocation( "data", "kmail/autosave", false );
   if ( !autoSaveDir.isEmpty() ) {
@@ -218,6 +219,15 @@ void KMailMigrator::deleteOldGroup( const QString& name ) {
   }
 }
 
+void KMailMigrator::migrateNotifyFile()
+{
+    const QString notifyFile = KStandardDirs::locate( "config", "kmail.notifyrc" );
+    if ( !notifyFile.isEmpty() ) {
+        QFile::copy( notifyFile, KStandardDirs::locateLocal("config", "kmail2.notifyrc"));
+    }
+
+}
+
 void KMailMigrator::migrateTags()
 {
   KConfigGroup tagMigrationConfig( KGlobal::config(), QLatin1String( "MessageTags" ) );
@@ -972,7 +982,7 @@ void KMailMigrator::maildirAccountCreated( KJob *job )
 void KMailMigrator::localMaildirCreated( KJob *job )
 {
   if ( job->error() ) {
-    emit message( Error, i18n( "Failed to resource for local folders: %1", job->errorText() ) );
+    emit message( Error, i18n( "Failed to create resource for local folders: %1", job->errorText() ) );
     deleteLater();
     return;
   }
